@@ -6,6 +6,7 @@ from copy import deepcopy
 
 import pymongo
 from bson import ObjectId
+from bson.errors import InvalidId
 
 from scout.build import build_panel
 from scout.exceptions import IntegrityError
@@ -187,7 +188,10 @@ class PanelHandler:
             dict: panel object or `None` if panel not found
         """
         if not isinstance(panel_id, ObjectId):
-            panel_id = ObjectId(panel_id)
+            try:
+                panel_id = ObjectId(panel_id)
+            except InvalidId as err:
+                LOG.error("Invalid panel id received: %s", err)
         panel_obj = self.panel_collection.find_one({"_id": panel_id})
         return panel_obj
 
@@ -224,7 +228,6 @@ class PanelHandler:
             query["version"] = version
             return self.panel_collection.find_one(query)
 
-        LOG.info("Fetching gene panels %s from database", panel_id)
         res = self.panel_collection.find(query).sort("version", -1)
 
         for panel in res:
