@@ -13,7 +13,11 @@ LOG = logging.getLogger(__name__)
 
 
 def upload_research_variants(
-    adapter: MongoAdapter, case_obj: dict, variant_type: str, category: str, rank_treshold: int
+    adapter: MongoAdapter,
+    case_obj: dict,
+    variant_type: str,
+    category: str,
+    rank_treshold: int,
 ):
     """Delete existing variants and upload new variants"""
     adapter.delete_variants(case_id=case_obj["_id"], variant_type=variant_type, category=category)
