@@ -2,24 +2,122 @@
 import logging
 import os.path
 
-from flask import flash
+from flask import flash, session
 from flask_login import current_user
 
 from scout.constants import CASE_SPECIFIC_TRACKS, HUMAN_REFERENCE, IGV_TRACKS
 from scout.server.extensions import cloud_tracks, store
-from scout.server.utils import institute_and_case
+from scout.server.utils import case_append_alignments, institute_and_case
 from scout.utils.ensembl_rest_clients import EnsemblRestApiClient
 
 LOG = logging.getLogger(__name__)
 CUSTOM_TRACK_NAMES = ["Genes", "ClinVar", "ClinVar CNVs"]
 
 
-def make_sashimi_tracks(institute_id, case_name, variant_id):
+def check_session_tracks(resource):
+    """Make sure that a user requesting a resource is authenticated and resource is in session IGV tracks
+
+    Args:
+        resource(str): a resource on the server or on a remote URL
+
+    Returns
+        True is user has access to resource else False
+    """
+    # Check that user is logged in or that file extension is valid
+    if current_user.is_authenticated is False:
+        LOG.warning("Unauthenticated user requesting resource via remote_static")
+        return False
+    if resource not in session.get("igv_tracks", []):
+        LOG.warning(f"Requested resource to be displayed in IGV not in session's IGV tracks")
+        return False
+    return True
+
+
+def set_session_tracks(display_obj):
+    """Save igv tracks as a session object. This way it's easy to verify that a user is requesting one of these files from remote_static view endpoint
+
+    Args:
+        display_obj(dict): A display object containing case name, list of genes, lucus and tracks
+    """
+    session_tracks = list(display_obj.get("reference_track", {}).values())
+    for key, track_items in display_obj.items():
+        if key not in ["tracks", "custom_tracks", "sample_tracks", "cloud_public_tracks"]:
+            continue
+        for track_item in track_items:
+            session_tracks += list(track_item.values())
+
+    session["igv_tracks"] = session_tracks
+
+
+def make_igv_tracks(case_obj, variant_id, chrom=None, start=None, stop=None):
+    """Create a dictionary containing the required tracks for displaying IGV tracks for case or a group of cases
+
+    Args:
+        institute_id(str): institute _id
+        case_obj(scout.models.Case)
+        variant_id(str): _id of a variant
+        chrom(str/None): requested chromosome [1-22], X, Y, [M-MT]
+        start(int/None): start of the genomic interval to be displayed
+        stop(int/None): stop of the genomic interval to be displayed
+
+    Returns:
+        display_obj(dict): A display object containing case name, list of genes, lucus and tracks
+    """
+    display_obj = {}
+    variant_obj = store.variant(document_id=variant_id)
+
+    if variant_obj:
+        # Set display locus
+        start = start or variant_obj["position"]
+        stop = stop or variant_obj["end"]
+
+        chromosome = chrom or variant_obj.get("chromosome")
+        chromosome = chromosome.replace("MT", "M")
+        display_obj["locus"] = "chr{0}:{1}-{2}".format(chromosome, start, stop)
+    else:
+        chromosome = "All"
+
+    # Set genome build for displaying alignments:
+    if "38" in str(case_obj.get("genome_build", "37")) or chromosome == "M":
+        build = "38"
+    else:
+        build = "37"
+
+    # Set general tracks (Genes, Clinvar and ClinVar SNVs are shown according to user preferences)
+    set_common_tracks(display_obj, build)
+
+    # Build tracks for main case and all connected cases (cases grouped with main case)
+    grouped_cases = []
+    for group in case_obj.get("group", []):
+        group_cases = list(store.cases(group=group))
+        for case in group_cases:
+            case_append_alignments(case)  # Add track data to connected case dictionary
+            grouped_cases.append(case)
+
+    if not grouped_cases:  # Display case individuals tracks only
+        case_append_alignments(case_obj)  # Add track data to main case dictionary
+        grouped_cases.append(case_obj)
+
+    # Set up bam/cram alignments for case group samples:
+    set_sample_tracks(display_obj, grouped_cases, chromosome)
+
+    # When chrom != MT, set up case-specific tracks (might be present according to the pipeline)
+    if chrom != "M":
+        set_case_specific_tracks(display_obj, case_obj)
+
+    # Set up custom cloud public tracks, if available
+    set_cloud_public_tracks(display_obj, build)
+
+    display_obj["display_center_guide"] = True
+
+    return display_obj
+
+
+def make_sashimi_tracks(case_obj, variant_id):
     """Create a dictionary containing the required tracks for a splice junction plot
 
-    Accepts:
-        institute_id(str): institute _id
-        case_name(str): case display name
+    Args:
+        case_obj(scout.models.Case)
         variant_id(str) _id of a variant
     Returns:
         display_obj(dict): A display object containing case name, list of genes, lucus and tracks
@@ -27,7 +125,6 @@ def make_sashimi_tracks(institute_id, case_name, variant_id):
     build = "38"  # This feature is only available for RNA tracks in build 38
 
     variant_obj = store.variant(document_id=variant_id)
-    _, case_obj = institute_and_case(store, institute_id, case_name)
 
     # Initialize locus coordinates it with variant coordinates so it won't crash if variant gene(s) no longer exist in database
     locus_start_coords = []
@@ -97,7 +194,7 @@ def make_sashimi_tracks(institute_id, case_name, variant_id):
     return display_obj
 
 
-def make_igv_tracks(name, file_list):
+def set_tracks(name, file_list):
     """Return a dict according to IGV track format."""
     track_list = []
     for track in file_list:
@@ -127,42 +224,43 @@ def set_common_tracks(display_obj, build):
             display_obj["custom_tracks"].append(track)
 
 
-def set_sample_tracks(display_obj, form):
+def set_sample_tracks(display_obj, case_groups, chromosome):
     """Set up individual-specific alignment tracks (bam/cram files)
 
     Args:
-        display_obj(dict) dictionary containing all tracks info
-        form(dict) flask request form dictionary
+        display_obj(dict): dictionary containing all tracks info
+        case_groups(list): a list of case dictionaries
+        chromosome(str) [1-22],X,Y,M or "All"
     """
-    samples = form.get("sample").split(",")
     sample_tracks = []
-    bam_files = None
-    bai_files = None
-    if form.get("align") == "mt_bam":
-        bam_files = form.get("mt_bam").split(",")
-        bai_files = form.get("mt_bai").split(",")
-    elif form.get("align") == "bam":
-        bam_files = form.get("bam").split(",")
-        bai_files = form.get("bai").split(",")
 
-    counter = 0
-    for sample in samples:
-        # some samples might not have an associated bam file, take care if this
-        if len(bam_files) > counter and bam_files[counter]:
+    track_items = "mt_bams" if chromosome == "M" else "bam_files"
+    track_index_items = "mt_bais" if track_items == "mt_bams" else "bai_files"
+
+    # Loop over a group of cases and add tracks for every individual of of every case
+    for case in case_groups:
+        if None in [
+            case.get("sample_names"),
+            case.get(track_items),
+            case.get(track_index_items),
+        ]:
+            case["sample_tracks"] = []
+            return
+
+        for count, sample in enumerate(case.get("sample_names")):
             sample_tracks.append(
                 {
                     "name": sample,
-                    "url": bam_files[counter],
-                    "format": bam_files[counter].split(".")[-1],  # "bam" or "cram"
-                    "indexURL": bai_files[counter],
+                    "url": case[track_items][count],
+                    "indexURL": case[track_index_items][count],
+                    "format": case[track_items][count].split(".")[-1],  # "bam" or "cram"
                     "height": 700,
                 }
             )
-        counter += 1
-    display_obj["sample_tracks"] = sample_tracks
+        display_obj["sample_tracks"] = sample_tracks
 
 
-def set_case_specific_tracks(display_obj, form):
+def set_case_specific_tracks(display_obj, case_obj):
     """Set up tracks from files that might be present or not at the case level
         (rhocall files, tiddit coverage files, upd regions and sites files)
     Args:
@@ -170,9 +268,10 @@ def set_case_specific_tracks(display_obj, form):
         form(dict) flask request form dictionary
     """
     for track, label in CASE_SPECIFIC_TRACKS.items():
-        if form.get(track):
-            track_info = make_igv_tracks(label, form.get(track).split(","))
-            display_obj[track] = track_info
+        if case_obj.get(track) is None:
+            continue
+        track_info = set_tracks(label, case_obj.get(track).split(","))
+        display_obj[track] = track_info
 
 
 def set_cloud_public_tracks(display_obj, build):
