@@ -23,7 +23,7 @@ from flask import (
 from flask_login import current_user
 
 from scout.constants import CUSTOM_CASE_REPORTS
-from scout.server.extensions import mail, store
+from scout.server.extensions import beacon, mail, store
 from scout.server.utils import (
     html_to_pdf_file,
     institute_and_case,
@@ -84,19 +84,23 @@ def sma(institute_id, case_name):
     return dict(format="html", **data)
 
 
-@cases_bp.route("/beacon_submit", methods=["POST"])
-def beacon_submit():
+@cases_bp.route("/beacon_add_variants/<institute_id>/<case_name>", methods=["POST"])
+def beacon_add_variants(institute_id, case_name):
     """Submit case variants to Beacon"""
-
-    controllers.beacon_add(request.form)
+    _, case_obj = institute_and_case(
+        store, institute_id, case_name
+    )  # This function checks if user has permissions to access the case
+    beacon.add_variants(store, case_obj, request.form)
     return redirect(request.referrer)
 
 
-@cases_bp.route("/beacon_remove/<case_id>", methods=["GET"])
-def beacon_remove(case_id):
+@cases_bp.route("/beacon_remove_variants/<institute_id>/<case_name>", methods=["GET"])
+def beacon_remove_variants(institute_id, case_name):
     """Remove all variants from a case from Beacon"""
-
-    controllers.beacon_remove(case_id)
+    _, case_obj = institute_and_case(
+        store, institute_id, case_name
+    )  # This function checks if user has permissions to access the case
+    beacon.remove_variants(store, institute_id, case_obj)
     return redirect(request.referrer)
 
 
@@ -244,7 +248,7 @@ def pdf_case_report(institute_id, case_name):
     )
     return send_file(
         bytes_file,
-        attachment_filename=file_name,
+        download_name=file_name,
         mimetype="application/pdf",
         as_attachment=True,
     )
@@ -255,7 +259,9 @@ def mt_report(institute_id, case_name):
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
 
     # create a temp folder to write excel files into
-    temp_excel_dir = os.path.join(cases_bp.static_folder, "_".join([case_name, "mt_reports"]))
+    temp_excel_dir = os.path.join(
+        cases_bp.static_folder, "_".join([case_obj["display_name"], "mt_reports"])
+    )
     os.makedirs(temp_excel_dir, exist_ok=True)
 
     if controllers.mt_excel_files(store, case_obj, temp_excel_dir):
@@ -268,7 +274,7 @@ def mt_report(institute_id, case_name):
             data,
             mimetype="application/zip",
             as_attachment=True,
-            attachment_filename="_".join(["scout", case_name, "MT_report", today]) + ".zip",
+            download_name="_".join(["scout", case_name, "MT_report", today]) + ".zip",
             cache_timeout=0,
         )
 
@@ -698,7 +704,7 @@ def delivery_report(institute_id, case_name):
             )
             return send_file(
                 bytes_file,
-                attachment_filename=file_name,
+                download_name=file_name,
                 mimetype="application/pdf",
                 as_attachment=True,
             )
@@ -767,7 +773,7 @@ def coverage_qc_report(institute_id, case_name):
                 )
                 return send_file(
                     bytes_file,
-                    attachment_filename=file_name,
+                    download_name=file_name,
                     mimetype="application/pdf",
                     as_attachment=True,
                 )
@@ -960,7 +966,7 @@ def download_hpo_genes(institute_id, case_name, category):
     )
     return send_file(
         bytes_file,
-        attachment_filename=file_name,
+        download_name=file_name,
         mimetype="application/pdf",
         as_attachment=True,
     )
@@ -976,13 +982,11 @@ def vcf2cytosure(institute_id, case_name, individual_id):
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     outdir = os.path.abspath(os.path.dirname(vcf2cytosure))
     filename = os.path.basename(vcf2cytosure)
-    attachment_filename = ".".join(
+    download_name = ".".join(
         [display_name, case_obj["display_name"], case_obj["_id"], "vcf2cytosure.cgh"]
     )
-    LOG.debug("Attempt to deliver file {0} from dir {1}".format(attachment_filename, outdir))
-    return send_from_directory(
-        outdir, filename, attachment_filename=attachment_filename, as_attachment=True
-    )
+    LOG.debug("Attempt to deliver file {0} from dir {1}".format(download_name, outdir))
+    return send_from_directory(outdir, filename, download_name=download_name, as_attachment=True)
 
 
 @cases_bp.route("/<institute_id>/<case_name>/multiqc")
