@@ -8,6 +8,7 @@ import shutil
 import pymongo
 from flask import Blueprint, flash, redirect, request, send_file, url_for
 from flask_login import current_user
+from markupsafe import Markup
 
 from scout.constants import (
     CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
@@ -45,7 +46,7 @@ def reset_dismissed(institute_id, case_name):
 @templated("variants/variants.html")
 def variants(institute_id, case_name):
     """Display a list of SNV variants."""
-    page = int(request.form.get("page", 1))
+    page = int(Markup.escape(request.form.get("page", "1")))
     category = "snv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = request.args.get("variant_type", "clinical")
@@ -123,7 +124,9 @@ def variants(institute_id, case_name):
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
 
-    data = controllers.variants(store, institute_obj, case_obj, variants_query, result_size, page)
+    data = controllers.variants(
+        store, institute_obj, case_obj, variants_query, result_size, page, query_form=form.data
+    )
     expand_search = request.method == "POST" and request.form.get("expand_search") in [
         "True",
         "",
@@ -150,8 +153,8 @@ def variants(institute_id, case_name):
 @templated("variants/str-variants.html")
 def str_variants(institute_id, case_name):
     """Display a list of STR variants."""
-    page = int(request.form.get("page", 1))
-    variant_type = request.args.get("variant_type", "clinical")
+    page = int(Markup.escape(request.form.get("page", "1")))
+    variant_type = Markup.escape(request.args.get("variant_type", "clinical"))
     category = "str"
 
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -231,8 +234,8 @@ def str_variants(institute_id, case_name):
 def sv_variants(institute_id, case_name):
     """Display a list of structural variants."""
 
-    page = int(request.form.get("page", 1))
-    variant_type = request.args.get("variant_type", "clinical")
+    page = int(Markup.escape(request.form.get("page", "1")))
+    variant_type = Markup.escape(request.args.get("variant_type", "clinical"))
     category = "sv"
     # Define case and institute objects
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -307,7 +310,7 @@ def sv_variants(institute_id, case_name):
 def cancer_variants(institute_id, case_name):
     """Show cancer variants overview."""
     category = "cancer"
-    variant_type = request.args.get("variant_type", "clinical")
+    variant_type = Markup.escape(request.args.get("variant_type", "clinical"))
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variants_stats = store.case_variants_count(case_obj["_id"], institute_id, variant_type, False)
 
@@ -328,7 +331,11 @@ def cancer_variants(institute_id, case_name):
         )
 
         # if user is not loading an existing filter, check filter form
-        if request.form.get("load_filter") is None and form.validate_on_submit() is False:
+        if (
+            request.form.get("load_filter") is None
+            and request.form.get("audit_filter") is None
+            and form.validate_on_submit() is False
+        ):
             # Flash a message with errors
             for field, err_list in form.errors.items():
                 for err in err_list:
@@ -342,10 +349,10 @@ def cancer_variants(institute_id, case_name):
                     expand_search=True,
                 )
             )
-        page = int(request.form.get("page", 1))
+        page = int(Markup.escape(request.form.get("page", "1")))
 
     else:
-        page = int(request.args.get("page", 1))
+        page = int(Markup.escape(request.args.get("page", "1")))
         form = CancerFiltersForm(request.args)
         # set chromosome to all chromosomes
         form.chrom.data = request.args.get("chrom", "")
@@ -411,8 +418,8 @@ def cancer_variants(institute_id, case_name):
 def cancer_sv_variants(institute_id, case_name):
     """Display a list of cancer structural variants."""
 
-    page = int(request.form.get("page", 1))
-    variant_type = request.args.get("variant_type", "clinical")
+    page = int(Markup.escape(request.form.get("page", "1")))
+    variant_type = Markup.escape(request.args.get("variant_type", "clinical"))
     category = "cancer_sv"
     # Define case and institute objects
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -556,7 +563,7 @@ def download_verified():
             data,
             mimetype="application/zip",
             as_attachment=True,
-            attachment_filename="_".join(["scout", "verified_variants", today]) + ".zip",
+            download_name="_".join(["scout", "verified_variants", today]) + ".zip",
             cache_timeout=0,
         )
 
