@@ -15,6 +15,20 @@ from flask_login import current_user
 LOG = logging.getLogger(__name__)
 
 
+def document_generated(document_id):
+    """Returns the generation time of a certain MongodDB document
+
+    Args:
+        document_id (bson.objectid.ObjectId)
+
+    Returns:
+        document_id.generation_time (datetime.datetime) or None if document_id is not of type ObjectId
+    """
+    if isinstance(document_id, ObjectId):
+        return document_id.generation_time
+    LOG.error(f"Could not retrieve generation date for Object {document_id}")
+
+
 def html_to_pdf_file(
     html_string, orientation, dpi=96, margins=["1.5cm", "1cm", "1cm", "1cm"], zoom=1
 ):
@@ -136,8 +150,6 @@ def variant_case(store, case_obj, variant_obj):
         variant_obj(scout.models.Variant)
     """
 
-    case_append_alignments(case_obj)
-
     chrom = None
     starts = []
     ends = []
@@ -161,6 +173,32 @@ def variant_case(store, case_obj, variant_obj):
         LOG.warning(err)
 
 
+def case_has_alignments(case_obj):
+    """Add info on bam/cram files availability to a case dictionary
+
+    Args:
+        case_obj(scout.models.Case)
+    """
+    case_obj["bam_files"] = False  # Availability of alignments for autosomal chromosomes
+    for ind in case_obj.get("individuals"):
+        if ind.get("bam_file") and ind.get("bam_file") != "":
+            case_obj["bam_files"] = True
+            return
+
+
+def case_has_mt_alignments(case_obj):
+    """Add info on MT bam files availability to a case dictionary
+
+    Args:
+        case_obj(scout.models.Case)
+    """
+    case_obj["mt_bams"] = False  # Availability of alignments for MT chromosome
+    for ind in case_obj.get("individuals"):
+        if ind.get("mt_bam") and ind.get("mt_bam") != "":
+            case_obj["mt_bams"] = True
+            return
+
+
 def case_append_alignments(case_obj):
     """Deconvolute information about files to case_obj.
 
@@ -195,13 +233,11 @@ def case_append_alignments(case_obj):
         append_safe(
             case_obj,
             "sample_names",
-            case_obj["display_name"] + " - " + individual.get("display_name"),
+            case_obj.get("display_name", "") + " - " + individual.get("display_name", ""),
         )
         for setting in unwrap_settings:
             file_path = individual.get(setting["path"])
-            LOG.debug("filepath %s: ", file_path)
             if not (file_path and os.path.exists(file_path)):
-                LOG.debug("%s: no bam/cram file found", individual["individual_id"])
                 continue
             append_safe(case_obj, setting["append_to"], file_path)
             if not setting["index"] == "no_index":
