@@ -65,3 +65,17 @@ def parsed_gene():
         "build": "37",
     }
     return gene_info
+
+
+@pytest.fixture
+def omim_term():
+    """Returns a test OMIM term as it is saved in the database"""
+    disease_term = dict(
+        _id="OMIM:1",
+        disease_id="OMIM:1",
+        disease_nr=1,
+        source="OMIM",
+        description="First disease",
+        genes=[1],  # List with integers that are hgnc_ids
+    )
+    return disease_term
