@@ -31,6 +31,7 @@ from scout.demo import (
     panel_path,
     ped_path,
     vep_97_annotated_path,
+    vep_104_annotated_path,
 )
 
 # These are the reduced data files
@@ -1014,6 +1015,15 @@ def one_vep97_annotated_variant(request, vep_97_annotated_variant_clinical_file)
     return variant
 
 
+@pytest.fixture(scope="function")
+def one_vep104_annotated_variant(request, vep_104_annotated_variant_clinical_file):
+    LOG.info("Return one parsed variant")
+    variant_parser = VCF(vep_104_annotated_variant_clinical_file)
+
+    variant = next(variant_parser)
+    return variant
+
+
 @pytest.fixture(scope="function")
 def one_cancer_manta_SV_variant(request, vep_94_manta_annotated_SV_variants_file):
     LOG.info("Return one parsed cancer SV variant")
@@ -1314,6 +1324,12 @@ def variant_clinical_file(request):
     return clinical_snv_path
 
 
+@pytest.fixture(scope="function")
+def vep_104_annotated_variant_clinical_file(request):
+    """Get a path to a VCF file annotated with VEP 104 MIP11, with CSQ.rs_dbSNP150 dbsnp_id."""
+    return vep_104_annotated_path
+
+
 @pytest.fixture(scope="function")
 def vep_97_annotated_variant_clinical_file(request):
     """Get a path to a VCF file annotated with VEP and containing conservation
@@ -1522,28 +1538,6 @@ def genemap_handle(request, genemap_file):
     return get_file_handle(genemap_file)
 
 
-#############################################################
-###################### Beacon Fixtures ######################
-#############################################################
-
-
-@pytest.fixture(scope="function")
-def mocked_beacon():
-    """A success response from a mocked Beacon server"""
-
-    class MockBeaconResponse:
-        def __init__(self):
-            self.status_code = 200
-            self.url = "http://beacon_url"
-            self.token = "xyz"
-
-        def json(self):
-            return {"message": "OK"}
-
-    resp = MockBeaconResponse()
-    return resp
-
-
 #############################################################
 #################### MatchMaker Fixtures ####################
 #############################################################
